@@ -26,34 +26,21 @@ def test_parser(tmpdir):
         ROOT / "data" / "core.yaml", "swift", tmpdir, {}, {"allow_reserved": True}
     )
 
-    assert set(x.name for x in tmpdir.iterdir()) == set(
-        [
-            "CorePing.swift",
-            "Telemetry.swift",
-            "Environment.swift",
-            "DottedCategory.swift",
-            "GleanInternalMetrics.swift",
-        ]
-    )
+    assert set(x.name for x in tmpdir.iterdir()) == set(["Metrics.swift"])
 
     # Make sure descriptions made it in
-    with (tmpdir / "CorePing.swift").open("r", encoding="utf-8") as fd:
+    with (tmpdir / "Metrics.swift").open("r", encoding="utf-8") as fd:
         content = fd.read()
+
         assert "True if the user has set Firefox as the default browser." in content
-
-    with (tmpdir / "Telemetry.swift").open("r", encoding="utf-8") as fd:
-        content = fd.read()
         assert "جمع 搜集" in content
-
-    with (tmpdir / "GleanInternalMetrics.swift").open("r", encoding="utf-8") as fd:
-        content = fd.read()
         assert 'category: ""' in content
 
     # Syntax check on the generated files.
     # Only run this test if swiftc is on the path.
     if shutil.which("swiftc"):
         for filepath in tmpdir.glob("*.swift"):
-            subprocess.check_call(["swiftc", "-dump-parse", filepath])
+            subprocess.check_call(["swiftc", "-parse", filepath])
 
     # Lint check on the generated files.
     # Only run this test if swiftlint is on the path.
@@ -141,7 +128,7 @@ def test_order_of_fields(tmpdir):
     )
 
     # Make sure descriptions made it in
-    fd = (tmpdir / "CorePing.swift").open("r", encoding="utf-8")
+    fd = (tmpdir / "Metrics.swift").open("r", encoding="utf-8")
     content = fd.read()
     fd.close()
 
@@ -177,7 +164,7 @@ def test_no_import_glean(tmpdir):
     )
 
     # Make sure descriptions made it in
-    fd = (tmpdir / "CorePing.swift").open("r", encoding="utf-8")
+    fd = (tmpdir / "Metrics.swift").open("r", encoding="utf-8")
     content = fd.read()
     fd.close()
 
@@ -190,8 +177,37 @@ def test_import_glean(tmpdir):
     translate.translate(ROOT / "data" / "smaller.yaml", "swift", tmpdir, {}, {})
 
     # Make sure descriptions made it in
-    fd = (tmpdir / "Telemetry.swift").open("r", encoding="utf-8")
+    fd = (tmpdir / "Metrics.swift").open("r", encoding="utf-8")
     content = fd.read()
     fd.close()
 
     assert "import Glean" in content
+
+
+def test_event_extra_keys_in_correct_order(tmpdir):
+    """
+    Assert that the extra keys appear in the parameter and the enumeration in
+    the same order.
+
+    https://bugzilla.mozilla.org/show_bug.cgi?id=1648768
+    """
+
+    tmpdir = Path(str(tmpdir))
+
+    translate.translate(
+        ROOT / "data" / "event_key_ordering.yaml",
+        "swift",
+        tmpdir,
+        {"namespace": "Foo"},
+    )
+
+    assert set(x.name for x in tmpdir.iterdir()) == set(["Metrics.swift"])
+
+    with (tmpdir / "Metrics.swift").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        content = " ".join(content.split())
+        assert (
+            "enum ExampleKeys: Int32, ExtraKeys "
+            "{ case alice = 0 case bob = 1 case charlie = 2" in content
+        )
+        assert 'allowedExtraKeys: ["alice", "bob", "charlie"]' in content
